@@ -44,14 +44,6 @@ SuspendSession::SuspendSession(QObject *parent)
 
         Q_EMIT resumingFromSuspend();
     });
-
-    connect(m_fadeEffect.data(), &PowerDevil::KWinKScreenHelperEffect::fadedOut, this, [this]() {
-        if (!m_savedArgs.isEmpty()) {
-            QVariantMap args = m_savedArgs;
-            args["SkipFade"] = true;
-            triggerImpl(args);
-        }
-    });
 }
 
 SuspendSession::~SuspendSession() = default;
@@ -63,16 +55,18 @@ void SuspendSession::onWakeupFromIdle()
 
 void SuspendSession::onIdleTimeout(std::chrono::milliseconds timeout)
 {
-    QVariantMap args{{QStringLiteral("Type"), qToUnderlying(m_autoSuspendAction)}};
+    PolicyAgent::RequiredPolicies unsatisfiablePolicies = PolicyAgent::instance()->requirePolicyCheck(PowerDevil::PolicyAgent::InterruptSession);
+    if (unsatisfiablePolicies != PolicyAgent::None) {
+        return;
+    }
 
     // we fade the screen to black 5 seconds prior to suspending to alert the user
     if (timeout == m_idleTime - 5s) {
-        args.insert(QStringLiteral("GraceFade"), true);
+        m_fadeEffect->start();
     } else {
-        args.insert(QStringLiteral("SkipFade"), true);
+        QVariantMap args{{QStringLiteral("Type"), qToUnderlying(m_autoSuspendAction)}};
+        triggerImpl(args);
     }
-
-    trigger(args);
 }
 
 void SuspendSession::triggerImpl(const QVariantMap &args)
@@ -81,50 +75,34 @@ void SuspendSession::triggerImpl(const QVariantMap &args)
 
     const auto mode = static_cast<PowerDevil::PowerButtonAction>(args["Type"].toUInt());
 
-    switch (mode) {
-    case PowerDevil::PowerButtonAction::SuspendToRam:
-    case PowerDevil::PowerButtonAction::SuspendToDisk:
-    case PowerDevil::PowerButtonAction::SuspendHybrid:
+    if (mode == PowerDevil::PowerButtonAction::Sleep || mode == PowerDevil::PowerButtonAction::Hibernate) {
         // don't suspend if shutting down
         if (QDBusConnection::sessionBus().interface()->isServiceRegistered(QStringLiteral("org.kde.Shutdown"))) {
             qCDebug(POWERDEVIL) << "Not suspending because a shutdown is in progress";
             return;
         }
-
-        if (!args["SkipFade"].toBool()) {
-            m_savedArgs = args;
-            m_fadeEffect->start();
-            return;
-        }
-    default:
-        /* no suspend action => no fade effect */;
-    }
-
-    if (args["GraceFade"].toBool()) {
-        return;
     }
 
     // Switch for real action
     switch (static_cast<PowerDevil::PowerButtonAction>(args["Type"].toUInt())) {
-    case PowerDevil::PowerButtonAction::SuspendToRam:
+    case PowerDevil::PowerButtonAction::Sleep: {
         Q_EMIT aboutToSuspend();
+        auto sleepMode = args.contains("SleepMode") ? static_cast<PowerDevil::SleepMode>(args["SleepMode"].toUInt()) : m_sleepMode;
 
-        if (m_sleepMode == PowerDevil::SleepMode::SuspendThenHibernate) {
+        if (sleepMode == PowerDevil::SleepMode::SuspendThenHibernate) {
             core()->suspendController()->suspendThenHibernate();
-        } else if (m_sleepMode == PowerDevil::SleepMode::HybridSuspend) {
+        } else if (sleepMode == PowerDevil::SleepMode::HybridSuspend) {
             core()->suspendController()->hybridSuspend();
         } else {
             core()->suspendController()->suspend();
         }
         break;
-    case PowerDevil::PowerButtonAction::SuspendToDisk:
+    }
+    case PowerDevil::PowerButtonAction::Hibernate: {
         Q_EMIT aboutToSuspend();
         core()->suspendController()->hibernate();
         break;
-    case PowerDevil::PowerButtonAction::SuspendHybrid:
-        Q_EMIT aboutToSuspend();
-        core()->suspendController()->hybridSuspend();
-        break;
+    }
     case PowerDevil::PowerButtonAction::Shutdown: {
         SessionManagement sessionManager;
         sessionManager.requestShutdown(SessionManagement::ConfirmationMode::Skip);
@@ -164,29 +142,33 @@ bool SuspendSession::loadAction(const PowerDevil::ProfileSettings &profileSettin
     return true;
 }
 
-void SuspendSession::suspendHybrid()
-{
-    triggerSuspendSession(PowerDevil::PowerButtonAction::SuspendHybrid);
-}
-
 void SuspendSession::suspendToDisk()
 {
-    triggerSuspendSession(PowerDevil::PowerButtonAction::SuspendToDisk);
+    triggerSuspendSession(PowerDevil::PowerButtonAction::Hibernate);
 }
 
 void SuspendSession::suspendToRam()
 {
-    triggerSuspendSession(PowerDevil::PowerButtonAction::SuspendToRam);
+    triggerImpl({
+        {QStringLiteral("Type"), qToUnderlying(PowerDevil::PowerButtonAction::Sleep)},
+        {QStringLiteral("SleepMode"), qToUnderlying(PowerDevil::SleepMode::SuspendToRam)},
+    });
+}
+
+void SuspendSession::suspendHybrid()
+{
+    triggerImpl({
+        {QStringLiteral("Type"), qToUnderlying(PowerDevil::PowerButtonAction::Sleep)},
+        {QStringLiteral("SleepMode"), qToUnderlying(PowerDevil::SleepMode::HybridSuspend)},
+    });
 }
 
 void SuspendSession::triggerSuspendSession(PowerDevil::PowerButtonAction action)
 {
-    trigger({
+    triggerImpl({
         {QStringLiteral("Type"), qToUnderlying(action)},
-        {QStringLiteral("Explicit"), true},
     });
 }
-
 }
 #include "suspendsession.moc"
 
