@@ -6,6 +6,7 @@
  */
 
 #include "ProfilesConfigKCM.h"
+#include "ExternalServiceSettings.h"
 
 // powerdevil/kcmodule/common
 #include <PowerButtonActionModel.h>
@@ -13,6 +14,7 @@
 #include <SleepModeModel.h>
 
 // powerdevil/daemon
+#include <PowerDevilGlobalSettings.h>
 #include <PowerDevilProfileSettings.h>
 #include <lidcontroller.h>
 #include <powerdevilenums.h>
@@ -37,15 +39,68 @@
 #include <QQuickItem>
 #include <QQuickRenderControl>
 
-K_PLUGIN_CLASS_WITH_JSON(PowerDevil::ProfilesConfigKCM, "kcm_powerdevilprofilesconfig.json")
+K_PLUGIN_FACTORY_WITH_JSON(PowerDevilProfilesConfigFactory, "kcm_powerdevilprofilesconfig.json", {
+    registerPlugin<PowerDevil::ProfilesConfigKCM>();
+    registerPlugin<PowerDevil::ProfilesConfigData>();
+})
 
 namespace PowerDevil
 {
 
-ProfileConfigData::ProfileConfigData(const QString &profileId, bool isMobile, bool isVM, bool canSuspend, QObject *parent)
+ProfilesConfigData::ProfilesConfigData(QObject *parent, const KPluginMetaData &metaData)
+    : ProfilesConfigData(parent,
+                         Kirigami::Platform::TabletModeWatcher::self()->isTabletMode() /*isMobile*/,
+                         PowerDevil::PowerManagement::instance()->isVirtualMachine() /*isVM*/,
+                         PowerDevil::PowerManagement::instance()->canSuspend(),
+                         PowerDevil::PowerManagement::instance()->canHibernate())
+{
+    Q_UNUSED(metaData);
+}
+
+ProfilesConfigData::ProfilesConfigData(QObject *parent, bool isMobile, bool isVM, bool canSuspend, bool canHibernate)
     : KCModuleData(parent)
-    , m_profileId(profileId)
-    , m_settings(new ProfileSettings(profileId, isMobile, isVM, canSuspend, this))
+    , m_globalSettings(new GlobalSettings(canSuspend, canHibernate, this))
+    , m_settingsAC(new ProfileSettings("AC", isMobile, isVM, canSuspend, this))
+    , m_settingsBattery(new ProfileSettings("Battery", isMobile, isVM, canSuspend, this))
+    , m_settingsLowBattery(new ProfileSettings("LowBattery", isMobile, isVM, canSuspend, this))
+{
+    autoRegisterSkeletons();
+}
+
+ProfilesConfigData::~ProfilesConfigData()
+{
+}
+
+GlobalSettings *ProfilesConfigData::global() const
+{
+    return m_globalSettings;
+}
+
+ProfileSettings *ProfilesConfigData::profileAC() const
+{
+    return m_settingsAC;
+}
+
+ProfileSettings *ProfilesConfigData::profileBattery() const
+{
+    return m_settingsBattery;
+}
+
+ProfileSettings *ProfilesConfigData::profileLowBattery() const
+{
+    return m_settingsLowBattery;
+}
+
+ProfilesConfigKCM::ProfilesConfigKCM(QObject *parent, const KPluginMetaData &metaData)
+    : KQuickManagedConfigModule(parent, metaData)
+    , m_settings(new ProfilesConfigData(this, metaData))
+    , m_externalServiceSettings(new ExternalServiceSettings(this))
+    , m_supportsBatteryProfiles(false)
+    , m_isPowerSupplyBatteryPresent(false)
+    , m_isPeripheralBatteryPresent(false)
+    , m_isLidPresent(false)
+    , m_isPowerButtonPresent(false)
+    , m_powerManagementServiceRegistered(false)
     , m_autoSuspendActionModel(new PowerButtonActionModel(this,
                                                           PowerManagement::instance(),
                                                           {
@@ -55,6 +110,14 @@ ProfileConfigData::ProfileConfigData(const QString &profileId, bool isMobile, bo
                                                               PowerButtonAction::Shutdown,
                                                               PowerButtonAction::LockScreen,
                                                           }))
+    , m_batteryCriticalActionModel(new PowerButtonActionModel(this,
+                                                              PowerManagement::instance(),
+                                                              {
+                                                                  PowerButtonAction::NoAction,
+                                                                  PowerButtonAction::Sleep,
+                                                                  PowerButtonAction::Hibernate,
+                                                                  PowerButtonAction::Shutdown,
+                                                              }))
     , m_powerButtonActionModel(new PowerButtonActionModel(this,
                                                           PowerManagement::instance(),
                                                           {
@@ -78,65 +141,22 @@ ProfileConfigData::ProfileConfigData(const QString &profileId, bool isMobile, bo
                                                   }))
     , m_sleepModeModel(new SleepModeModel(this, PowerManagement::instance()))
     , m_powerProfileModel(new PowerProfileModel(this))
-{
-    autoRegisterSkeletons();
-}
-
-ProfileConfigData::~ProfileConfigData()
-{
-}
-
-QString ProfileConfigData::profileId() const
-{
-    return m_profileId;
-}
-
-ProfileSettings *ProfileConfigData::settings() const
-{
-    return m_settings;
-}
-
-QObject *ProfileConfigData::autoSuspendActionModel() const
-{
-    return m_autoSuspendActionModel;
-}
-
-QObject *ProfileConfigData::powerButtonActionModel() const
-{
-    return m_powerButtonActionModel;
-}
-
-QObject *ProfileConfigData::lidActionModel() const
-{
-    return m_lidActionModel;
-}
-
-QObject *ProfileConfigData::sleepModeModel() const
-{
-    return m_sleepModeModel;
-}
-
-QObject *ProfileConfigData::powerProfileModel() const
-{
-    return m_powerProfileModel;
-}
-
-ProfilesConfigKCM::ProfilesConfigKCM(QObject *parent, const KPluginMetaData &metaData)
-    : KQuickManagedConfigModule(parent, metaData)
-    , m_supportsBatteryProfiles(false)
-    , m_isLidPresent(false)
-    , m_isPowerButtonPresent(false)
-    , m_powerManagementServiceRegistered(false)
 {
     qmlRegisterUncreatableMetaObject(PowerDevil::staticMetaObject, "org.kde.powerdevil", 1, 0, "PowerDevil", QStringLiteral("For enums and flags only"));
 
-    bool isMobile = Kirigami::Platform::TabletModeWatcher::self()->isTabletMode();
-    bool isVM = PowerDevil::PowerManagement::instance()->isVirtualMachine();
-    bool canSuspend = PowerDevil::PowerManagement::instance()->canSuspend();
-
-    m_profileData.insert("AC", QVariant::fromValue(new ProfileConfigData("AC", isMobile, isVM, canSuspend, this)));
-    m_profileData.insert("Battery", QVariant::fromValue(new ProfileConfigData("Battery", isMobile, isVM, canSuspend, this)));
-    m_profileData.insert("LowBattery", QVariant::fromValue(new ProfileConfigData("LowBattery", isMobile, isVM, canSuspend, this)));
+    connect(m_externalServiceSettings, &ExternalServiceSettings::settingsChanged, this, &ProfilesConfigKCM::settingsChanged);
+    connect(m_externalServiceSettings,
+            &ExternalServiceSettings::isChargeStartThresholdSupportedChanged,
+            this,
+            &ProfilesConfigKCM::isChargeStartThresholdSupportedChanged);
+    connect(m_externalServiceSettings,
+            &ExternalServiceSettings::isChargeStopThresholdSupportedChanged,
+            this,
+            &ProfilesConfigKCM::isChargeStopThresholdSupportedChanged);
+    connect(m_externalServiceSettings,
+            &ExternalServiceSettings::chargeStopThresholdMightNeedReconnectChanged,
+            this,
+            &ProfilesConfigKCM::chargeStopThresholdMightNeedReconnectChanged);
 
     QDBusServiceWatcher *watcher = new QDBusServiceWatcher("org.kde.Solid.PowerManagement",
                                                            QDBusConnection::sessionBus(),
@@ -187,12 +207,19 @@ ProfilesConfigKCM::ProfilesConfigKCM(QObject *parent, const KPluginMetaData &met
 
 void ProfilesConfigKCM::load()
 {
+    QWindow *renderWindowAsKAuthParent = QQuickRenderControl::renderWindowFor(mainUi()->window());
+    m_externalServiceSettings->load(renderWindowAsKAuthParent);
+
     const auto devices = Solid::Device::listFromType(Solid::DeviceInterface::Battery, QString());
     for (const Solid::Device &device : devices) {
         const Solid::Battery *b = qobject_cast<const Solid::Battery *>(device.asDeviceInterface(Solid::DeviceInterface::Battery));
-        if (b->isPowerSupply() && (b->type() == Solid::Battery::PrimaryBattery || b->type() == Solid::Battery::UpsBattery)) {
-            setSupportsBatteryProfiles(true);
-            break;
+        if (b->isPowerSupply()) {
+            setPowerSupplyBatteryPresent(true);
+            if (b->type() == Solid::Battery::PrimaryBattery || b->type() == Solid::Battery::UpsBattery) {
+                setSupportsBatteryProfiles(true);
+            }
+        } else {
+            setPeripheralBatteryPresent(true);
         }
     }
 
@@ -206,20 +233,33 @@ void ProfilesConfigKCM::save()
 {
     KQuickManagedConfigModule::save();
 
+    QWindow *renderWindowAsKAuthParent = QQuickRenderControl::renderWindowFor(mainUi()->window());
+    m_externalServiceSettings->save(renderWindowAsKAuthParent);
+
     // Notify daemon
     QDBusMessage call =
         QDBusMessage::createMethodCall("org.kde.Solid.PowerManagement", "/org/kde/Solid/PowerManagement", "org.kde.Solid.PowerManagement", "refreshStatus");
     QDBusConnection::sessionBus().asyncCall(call);
 }
 
+bool ProfilesConfigKCM::isSaveNeeded() const
+{
+    return m_externalServiceSettings->isSaveNeeded();
+}
+
 QVariantMap ProfilesConfigKCM::supportedActions() const
 {
     return m_supportedActions;
 }
 
-QVariantMap ProfilesConfigKCM::profileData() const
+ProfilesConfigData *ProfilesConfigKCM::settings() const
 {
-    return m_profileData;
+    return m_settings;
+}
+
+ExternalServiceSettings *ProfilesConfigKCM::externalServiceSettings() const
+{
+    return m_externalServiceSettings;
 }
 
 QString ProfilesConfigKCM::currentProfile() const
@@ -250,6 +290,49 @@ void ProfilesConfigKCM::setSupportsBatteryProfiles(bool supportsBatteryProfiles)
     Q_EMIT supportsBatteryProfilesChanged();
 }
 
+bool ProfilesConfigKCM::isChargeStartThresholdSupported() const
+{
+    return m_externalServiceSettings->isChargeStartThresholdSupported();
+}
+
+bool ProfilesConfigKCM::isChargeStopThresholdSupported() const
+{
+    return m_externalServiceSettings->isChargeStopThresholdSupported();
+}
+
+bool ProfilesConfigKCM::chargeStopThresholdMightNeedReconnect() const
+{
+    return m_externalServiceSettings->chargeStopThresholdMightNeedReconnect();
+}
+
+bool ProfilesConfigKCM::isPowerSupplyBatteryPresent() const
+{
+    return m_isPowerSupplyBatteryPresent;
+}
+
+bool ProfilesConfigKCM::isPeripheralBatteryPresent() const
+{
+    return m_isPeripheralBatteryPresent;
+}
+
+void ProfilesConfigKCM::setPowerSupplyBatteryPresent(bool isBatteryPresent)
+{
+    if (isBatteryPresent == m_isPowerSupplyBatteryPresent) {
+        return;
+    }
+    m_isPowerSupplyBatteryPresent = isBatteryPresent;
+    Q_EMIT isPowerSupplyBatteryPresentChanged();
+}
+
+void ProfilesConfigKCM::setPeripheralBatteryPresent(bool isBatteryPresent)
+{
+    if (isBatteryPresent == m_isPeripheralBatteryPresent) {
+        return;
+    }
+    m_isPeripheralBatteryPresent = isBatteryPresent;
+    Q_EMIT isPeripheralBatteryPresentChanged();
+}
+
 bool ProfilesConfigKCM::isLidPresent() const
 {
     return m_isLidPresent;
@@ -278,6 +361,36 @@ void ProfilesConfigKCM::setPowerButtonPresent(bool isPowerButtonPresent)
     Q_EMIT isPowerButtonPresentChanged();
 }
 
+QObject *ProfilesConfigKCM::autoSuspendActionModel() const
+{
+    return m_autoSuspendActionModel;
+}
+
+QObject *ProfilesConfigKCM::batteryCriticalActionModel() const
+{
+    return m_batteryCriticalActionModel;
+}
+
+QObject *ProfilesConfigKCM::powerButtonActionModel() const
+{
+    return m_powerButtonActionModel;
+}
+
+QObject *ProfilesConfigKCM::lidActionModel() const
+{
+    return m_lidActionModel;
+}
+
+QObject *ProfilesConfigKCM::sleepModeModel() const
+{
+    return m_sleepModeModel;
+}
+
+QObject *ProfilesConfigKCM::powerProfileModel() const
+{
+    return m_powerProfileModel;
+}
+
 bool ProfilesConfigKCM::powerManagementServiceRegistered() const
 {
     return m_powerManagementServiceRegistered;
